ExecuteMsg

Enum ExecuteMsg 

pub enum ExecuteMsg {
    UpdateAdmin {
        admin: Option<String>,
    },
    UpdateMembers {
        remove: Vec<String>,
        add: Vec<Member>,
    },
    AddPoints {
        addr: String,
        points: u64,
    },
    AddHook {
        addr: String,
    },
    RemoveHook {
        addr: String,
    },
    DistributeRewards {
        sender: Option<String>,
    },
    WithdrawRewards {
        owner: Option<String>,
        receiver: Option<String>,
    },
    DelegateWithdrawal {
        delegated: String,
    },
    AddSlasher {
        addr: String,
    },
    RemoveSlasher {
        addr: String,
    },
    Slash {
        addr: String,
        portion: Decimal,
    },
}

Variants



UpdateAdmin

Change the admin

Fields



UpdateMembers

apply a diff to the existing members. remove is applied after add, so if an address is in both, it is removed

Fields

remove: Vec<String>


AddPoints

Add points to member’s address

Fields

addr: String
points: u64


AddHook

Add a new hook to be informed of all membership changes. Must be called by Admin

Fields

addr: String


RemoveHook

Remove a hook. Must be called by Admin

Fields

addr: String


DistributeRewards

Distributes rewards sent with this message, and all rewards transferred since last call of this to members, proportionally to their points. Rewards are not immediately send to members, but assigned to them for later withdrawal (see: ExecuteMsg::WithdrawFunds)

Fields

sender: Option<String>

Original source of rewards, informational. If present overwrites “sender” field on propagated event.



WithdrawRewards

Withdraws rewards which were previously distributed and assigned to sender.

Fields

owner: Option<String>

Account from which assigned rewards would be withdrawn; sender by default. sender has to be eligible for withdrawal from owner address to perform this call (owner has to call DelegateWithdrawal { delegated: sender } before)

receiver: Option<String>

Address where to transfer funds. If not present, funds would be sent to sender.



DelegateWithdrawal

Sets given address as allowed for senders funds withdrawal. Funds still can be withdrawn by sender himself, but this additional account is allowed to perform it as well. There can be only one account delegated for withdrawal for any owner at any single time.

Fields

delegated: String

Account delegated for withdrawal. To disallow current withdrawal, the best is to set it to own address.



AddSlasher

Adds slasher for contract if there are enough slasher_preauths left

Fields

addr: String


RemoveSlasher

Removes slasher for contract

Fields

addr: String


Slash

Slash engagement points from address

Fields

addr: String
portion: Decimal