pub enum QueryMsg {
Show 16 variants
Admin {},
TotalPoints {},
ListMembers {
start_after: Option<String>,
limit: Option<u32>,
},
ListMembersByPoints {
start_after: Option<Member>,
limit: Option<u32>,
},
Member {
addr: String,
at_height: Option<u64>,
},
Hooks {},
Preauths {},
WithdrawableRewards {
owner: String,
},
DistributedRewards {},
UndistributedRewards {},
Delegated {
owner: String,
},
Halflife {},
IsSlasher {
addr: String,
},
ListSlashers {},
DistributionData {},
WithdrawAdjustmentData {
addr: String,
},
}Variants
Admin
Return AdminResponse
TotalPoints
Return TotalPointsResponse
ListMembers
Returns MemberListResponse
ListMembersByPoints
Returns MemberListResponse, sorted by points descending
Member
Returns MemberResponse
Hooks
Shows all registered hooks. Returns HooksResponse.
Preauths
Return the current number of preauths. Returns PreauthResponse.
WithdrawableRewards
Return how many rewards are assigned for withdrawal from the given address. Returns
RewardsResponse.
DistributedRewards
Return how many rewards were distributed in total by this contract. Returns
RewardsResponse.
UndistributedRewards
Return how many funds were sent to this contract since last ExecuteMsg::DistributeFunds,
and await for distribution. Returns RewardsResponse.
Delegated
Return address allowed for withdrawal of the funds assigned to owner. Returns DelegateResponse
Halflife
Returns information about the half-life, including the duration in seconds, the last and the next occurrence.
IsSlasher
Returns information (bool) about whether the given address is an active slasher
ListSlashers
Returns all active slashers as a vector of addresses
DistributionData
Returns rewards distribution data
WithdrawAdjustmentData
Returns withdraw adjustment data